"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSdk = exports.getExpenses_queryDocument = exports.getMeshSDK = exports.getBuiltMesh = exports.documentsInSDL = exports.getMeshOptions = exports.rawConfig = void 0;
const utils_1 = require("@graphql-mesh/utils");
const runtime_1 = require("@graphql-mesh/runtime");
const store_1 = require("@graphql-mesh/store");
const cross_helpers_1 = require("@graphql-mesh/cross-helpers");
const transpile_only_1 = __importDefault(require("ts-node/register/transpile-only"));
const cache_inmemory_lru_1 = __importDefault(require("@graphql-mesh/cache-inmemory-lru"));
const json_schema_1 = __importDefault(require("@graphql-mesh/json-schema"));
const merger_bare_1 = __importDefault(require("@graphql-mesh/merger-bare"));
const transform_resolvers_composition_1 = __importDefault(require("@graphql-mesh/transform-resolvers-composition"));
const jsonSchemaBundle_1 = __importDefault(require("./sources/Payper/jsonSchemaBundle"));
const getExpensesResolver_1 = __importDefault(require("./../src/resolvers/getExpensesResolver"));
const importedModules = {
    ["ts-node/register/transpile-only"]: transpile_only_1.default,
    ["@graphql-mesh/cache-inmemory-lru"]: cache_inmemory_lru_1.default,
    ["@graphql-mesh/json-schema"]: json_schema_1.default,
    ["@graphql-mesh/merger-bare"]: merger_bare_1.default,
    ["@graphql-mesh/transform-resolvers-composition"]: transform_resolvers_composition_1.default,
    [".mesh/sources/Payper/jsonSchemaBundle"]: jsonSchemaBundle_1.default,
    ["src/resolvers/getExpensesResolver"]: getExpensesResolver_1.default
};
const baseDir = cross_helpers_1.path.join(__dirname, '..');
const importFn = (moduleId) => {
    const relativeModuleId = (cross_helpers_1.path.isAbsolute(moduleId) ? cross_helpers_1.path.relative(baseDir, moduleId) : moduleId).split('\\').join('/').replace(baseDir + '/', '');
    if (!(relativeModuleId in importedModules)) {
        throw new Error(`Cannot find module '${relativeModuleId}'.`);
    }
    return Promise.resolve(importedModules[relativeModuleId]);
};
const rootStore = new store_1.MeshStore('.mesh', new store_1.FsStoreStorageAdapter({
    cwd: baseDir,
    importFn,
}), {
    readonly: true,
    validate: false
});
require("ts-node/register/transpile-only");
const utils_2 = require("@graphql-mesh/utils");
const cache_inmemory_lru_2 = __importDefault(require("@graphql-mesh/cache-inmemory-lru"));
const utils_3 = require("@graphql-mesh/utils");
const json_schema_2 = __importDefault(require("@graphql-mesh/json-schema"));
const merger_bare_2 = __importDefault(require("@graphql-mesh/merger-bare"));
const transform_resolvers_composition_2 = __importDefault(require("@graphql-mesh/transform-resolvers-composition"));
const utils_4 = require("@graphql-mesh/utils");
const utils_5 = require("@graphql-mesh/utils");
exports.rawConfig = { "sources": [{ "name": "Payper", "handler": { "jsonSchema": { "baseUrl": "https://payper.co.il/app/api", "operationHeaders": { "API_KEY": "{env.PAYPER_MESH_AUTH_TOKEN}", "Content-Type": "application/json", "Accept": "application/json" }, "operations": [{ "type": "Query", "field": "getExpenses", "path": "/pull_expenses", "method": "POST", "requestSchema": "./json-schemas/payperSchema.json#/definitions/getExpensesRequest", "responseSchema": "./json-schemas/payperSchema.json#/definitions/getExpensesResponse" }] } }, "transforms": [{ "resolversComposition": { "mode": "bare", "compositions": [{ "resolver": "Query.getExpenses", "composer": "src/resolvers/getExpensesResolver" }] } }] }], "serve": { "browser": false }, "sdk": { "generateOperations": { "selectionSetDepth": 2 } }, "require": ["ts-node/register/transpile-only"] };
async function getMeshOptions() {
    const pubsub = new utils_2.PubSub();
    const cache = new cache_inmemory_lru_2.default({
        ...(exports.rawConfig.cache || {}),
        importFn,
        store: rootStore.child('cache'),
        pubsub,
    });
    const sourcesStore = rootStore.child('sources');
    const logger = new utils_3.DefaultLogger('🕸️');
    const sources = [];
    const transforms = [];
    const payperTransforms = [];
    const additionalTypeDefs = [];
    const payperHandler = new json_schema_2.default({
        name: exports.rawConfig.sources[0].name,
        config: exports.rawConfig.sources[0].handler["jsonSchema"],
        baseDir,
        cache,
        pubsub,
        store: sourcesStore.child(exports.rawConfig.sources[0].name),
        logger: logger.child(exports.rawConfig.sources[0].name),
        importFn
    });
    const merger = new merger_bare_2.default({
        cache,
        pubsub,
        logger: logger.child('BareMerger'),
        store: rootStore.child('bareMerger')
    });
    payperTransforms.push(new transform_resolvers_composition_2.default({
        apiName: exports.rawConfig.sources[0].name,
        config: exports.rawConfig.sources[0].transforms[0]["resolversComposition"],
        baseDir,
        cache,
        pubsub,
        importFn
    }));
    sources.push({
        name: 'Payper',
        handler: payperHandler,
        transforms: payperTransforms
    });
    const additionalResolversRawConfig = [];
    const additionalResolvers = await (0, utils_4.resolveAdditionalResolvers)(baseDir, additionalResolversRawConfig, importFn, pubsub);
    const liveQueryInvalidations = exports.rawConfig.liveQueryInvalidations;
    const additionalEnvelopPlugins = [];
    const documents = exports.documentsInSDL.map((documentSdl, i) => ({
        rawSDL: documentSdl,
        document: (0, utils_5.parseWithCache)(documentSdl),
        location: `document_${i}.graphql`,
    }));
    return {
        sources,
        transforms,
        additionalTypeDefs,
        additionalResolvers,
        cache,
        pubsub,
        merger,
        logger,
        liveQueryInvalidations,
        additionalEnvelopPlugins,
        documents,
    };
}
exports.getMeshOptions = getMeshOptions;
exports.documentsInSDL = [];
async function getBuiltMesh() {
    const meshConfig = await getMeshOptions();
    return (0, runtime_1.getMesh)(meshConfig);
}
exports.getBuiltMesh = getBuiltMesh;
async function getMeshSDK(globalContext) {
    const { sdkRequesterFactory } = await getBuiltMesh();
    return getSdk(sdkRequesterFactory(globalContext));
}
exports.getMeshSDK = getMeshSDK;
exports.getExpenses_queryDocument = (0, utils_1.gql) `
    query getExpenses_query($input: getExpensesRequest_Input) {
  getExpenses(input: $input) {
    description
    expenses {
      created_at
      currency_symbol
      document_date
      document_id
      document_type
      file_name
      file_url
      foreign_total_for_payment
      original_file_name
      provider
      provider_business_num
      recognized_vat_payment
      remarks
      status_classification
      system_id
      total_for_payment
      total_for_vat
      updated_at
      vat_payment
    }
    next_page
    result
    total_entries
    total_pages
  }
}
    `;
function getSdk(requester) {
    return {
        getExpenses_query(variables, options) {
            return requester(exports.getExpenses_queryDocument, variables, options);
        }
    };
}
exports.getSdk = getSdk;
//# sourceMappingURL=index.js.map