import { compileQuery, isCompiledQuery } from 'graphql-jit';
import { AggregateError } from '@graphql-tools/utils';
import { getMesh } from '@graphql-mesh/runtime';
import { MeshStore, FsStoreStorageAdapter } from '@graphql-mesh/store';
import { join, relative, isAbsolute, dirname } from 'path';
import { fileURLToPath } from 'url';
import ExternalModule_0 from 'ts-node/register/transpile-only';
import ExternalModule_1 from '@graphql-mesh/cache-inmemory-lru';
import ExternalModule_2 from '@graphql-mesh/json-schema';
import ExternalModule_3 from '@graphql-mesh/merger-bare';
import ExternalModule_4 from '@graphql-mesh/transform-resolvers-composition';
import ExternalModule_5 from './sources/Payper/jsonSchema.json.cjs';
import ExternalModule_6 from './../src/resolvers/getExpensesResolver';
const importedModules = {
    // @ts-ignore
    ["ts-node/register/transpile-only"]: ExternalModule_0,
    // @ts-ignore
    ["@graphql-mesh/cache-inmemory-lru"]: ExternalModule_1,
    // @ts-ignore
    ["@graphql-mesh/json-schema"]: ExternalModule_2,
    // @ts-ignore
    ["@graphql-mesh/merger-bare"]: ExternalModule_3,
    // @ts-ignore
    ["@graphql-mesh/transform-resolvers-composition"]: ExternalModule_4,
    // @ts-ignore
    [".mesh/sources/Payper/jsonSchema.json.cjs"]: ExternalModule_5,
    // @ts-ignore
    ["src/resolvers/getExpensesResolver"]: ExternalModule_6
};
const baseDir = join(dirname(fileURLToPath(import.meta.url)), '..');
const importFn = (moduleId) => {
    const relativeModuleId = (isAbsolute(moduleId) ? relative(baseDir, moduleId) : moduleId).split('\\').join('/');
    if (!(relativeModuleId in importedModules)) {
        throw new Error(`Cannot find module '${relativeModuleId}'.`);
    }
    return Promise.resolve(importedModules[relativeModuleId]);
};
const rootStore = new MeshStore('.mesh', new FsStoreStorageAdapter({
    cwd: baseDir,
    importFn,
}), {
    readonly: true,
    validate: false
});
import 'ts-node/register/transpile-only';
import MeshCache from '@graphql-mesh/cache-inmemory-lru';
import { PubSub } from '@graphql-mesh/utils';
import { DefaultLogger } from '@graphql-mesh/utils';
import JsonSchemaHandler from '@graphql-mesh/json-schema';
import BareMerger from '@graphql-mesh/merger-bare';
import ResolversCompositionTransform from '@graphql-mesh/transform-resolvers-composition';
import { resolveAdditionalResolvers } from '@graphql-mesh/utils';
export const rawConfig = { "sources": [{ "name": "Payper", "handler": { "jsonSchema": { "baseUrl": "https://payper.co.il/app/api", "operationHeaders": { "API_KEY": "{env.PAYPER_MESH_AUTH_TOKEN}", "Content-Type": "application/json", "Accept": "application/json" }, "operations": [{ "type": "Query", "field": "getExpenses", "path": "/pull_expenses", "method": "POST", "requestSchema": "./json-schemas/payperSchema.json#/definitions/getExpensesRequest", "responseSchema": "./json-schemas/payperSchema.json#/definitions/getExpensesResponse" }] } }, "transforms": [{ "resolversComposition": { "mode": "bare", "compositions": [{ "resolver": "Query.getExpenses", "composer": "src/resolvers/getExpensesResolver" }] } }] }], "serve": { "browser": false }, "sdk": { "generateOperations": { "selectionSetDepth": 2 } }, "require": ["ts-node/register/transpile-only"] };
export async function getMeshOptions() {
    const cache = new MeshCache({
        ...(rawConfig.cache || {}),
        store: rootStore.child('cache'),
    });
    const pubsub = new PubSub();
    const sourcesStore = rootStore.child('sources');
    const logger = new DefaultLogger('🕸️');
    const sources = [];
    const transforms = [];
    const payperTransforms = [];
    const additionalTypeDefs = [];
    const payperHandler = new JsonSchemaHandler({
        name: rawConfig.sources[0].name,
        config: rawConfig.sources[0].handler["jsonSchema"],
        baseDir,
        cache,
        pubsub,
        store: sourcesStore.child(rawConfig.sources[0].name),
        logger: logger.child(rawConfig.sources[0].name),
        importFn
    });
    const merger = new BareMerger({
        cache,
        pubsub,
        logger: logger.child('BareMerger'),
        store: rootStore.child('bareMerger')
    });
    payperTransforms.push(new ResolversCompositionTransform({
        apiName: rawConfig.sources[0].name,
        config: rawConfig.sources[0].transforms[0]["resolversComposition"],
        baseDir,
        cache,
        pubsub,
        importFn
    }));
    sources.push({
        name: 'Payper',
        handler: payperHandler,
        transforms: payperTransforms
    });
    const additionalResolversRawConfig = [];
    const additionalResolvers = await resolveAdditionalResolvers(baseDir, additionalResolversRawConfig, importFn, pubsub);
    const liveQueryInvalidations = rawConfig.liveQueryInvalidations;
    return {
        sources,
        transforms,
        additionalTypeDefs,
        additionalResolvers,
        cache,
        pubsub,
        merger,
        logger,
        liveQueryInvalidations,
    };
}
export const documentsInSDL = /*#__PURE__*/ [];
export async function getBuiltMesh() {
    const meshConfig = await getMeshOptions();
    return getMesh(meshConfig);
}
export async function getMeshSDK(sdkOptions) {
    const { schema } = await getBuiltMesh();
    return getSdk(schema, {
        jitOptions: {
            disableLeafSerialization: true,
            disablingCapturingStackErrors: true
        },
        ...sdkOptions,
    });
}
export const getExpenses_queryDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "getExpenses_query" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "input" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "getExpensesRequest_Input" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "getExpenses" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "input" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "input" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "expenses" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "created_at" } }, { "kind": "Field", "name": { "kind": "Name", "value": "currency_symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "document_date" } }, { "kind": "Field", "name": { "kind": "Name", "value": "document_id" } }, { "kind": "Field", "name": { "kind": "Name", "value": "document_type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "file_name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "file_url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "foreign_total_for_payment" } }, { "kind": "Field", "name": { "kind": "Name", "value": "original_file_name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "provider" } }, { "kind": "Field", "name": { "kind": "Name", "value": "provider_business_num" } }, { "kind": "Field", "name": { "kind": "Name", "value": "recognized_vat_payment" } }, { "kind": "Field", "name": { "kind": "Name", "value": "remarks" } }, { "kind": "Field", "name": { "kind": "Name", "value": "status_classification" } }, { "kind": "Field", "name": { "kind": "Name", "value": "system_id" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_for_payment" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_for_vat" } }, { "kind": "Field", "name": { "kind": "Name", "value": "updated_at" } }, { "kind": "Field", "name": { "kind": "Name", "value": "vat_payment" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "next_page" } }, { "kind": "Field", "name": { "kind": "Name", "value": "result" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_entries" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_pages" } }] } }] } }] };
function handleExecutionResult(result, operationName) {
    if (result.errors) {
        const originalErrors = result.errors.map(error => error.originalError || error);
        throw new AggregateError(originalErrors, `Failed to execute ${operationName}: \n\t${originalErrors.join('\n\t')}`);
    }
    return result.data;
}
export function getSdk(schema, { globalContext, globalRoot, jitOptions = {} } = {}) {
    const getExpenses_queryCompiled = compileQuery(schema, getExpenses_queryDocument, 'getExpenses_query', jitOptions);
    if (!(isCompiledQuery(getExpenses_queryCompiled))) {
        const originalErrors = getExpenses_queryCompiled?.errors?.map(error => error.originalError || error) || [];
        throw new AggregateError(originalErrors, `Failed to compile getExpenses_query: \n\t${originalErrors.join('\n\t')}`);
    }
    return {
        async getExpenses_query(variables, context, root) {
            const result = await getExpenses_queryCompiled.query({
                ...globalRoot,
                ...root
            }, {
                ...globalContext,
                ...context
            }, variables);
            return handleExecutionResult(result, 'getExpenses_query');
        }
    };
}
