// @ts-nocheck
import { GraphQLResolveInfo } from 'graphql';
import { TypedDocumentNode as DocumentNode } from '@graphql-typed-document-node/core';
import { gql } from '@graphql-mesh/utils';

export type Maybe<T> = T | null;
export type InputMaybe<T> = Maybe<T>;
export type Exact<T extends { [key: string]: unknown }> = { [K in keyof T]: T[K] };
export type MakeOptional<T, K extends keyof T> = Omit<T, K> & { [SubKey in K]?: Maybe<T[SubKey]> };
export type MakeMaybe<T, K extends keyof T> = Omit<T, K> & { [SubKey in K]: Maybe<T[SubKey]> };
/** All built-in and custom scalars, mapped to their actual values */
export type Scalars = {
  ID: string;
  /** The `String` scalar type represents textual data, represented as UTF-8 character sequences. The String type is most often used by GraphQL to represent free-form human-readable text. */
  String: string;
  Boolean: boolean;
  /** The `Int` scalar type represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1. */
  Int: number;
  /** The `Float` scalar type represents signed double-precision fractional values as specified by [IEEE 754](https://en.wikipedia.org/wiki/IEEE_floating_point). */
  Float: number;
};

export type Query = {
  getExpenses?: Maybe<getExpensesResponse>;
};


export type QuerygetExpensesArgs = {
  input?: InputMaybe<getExpensesRequest_Input>;
};

export type getExpensesResponse = {
  description: Scalars['String'];
  /** An array of JSON of the search */
  expenses?: Maybe<Array<Maybe<Expense>>>;
  /** The next available page */
  next_page?: Maybe<Scalars['String']>;
  result: Scalars['Int'];
  /** The total size of the query */
  total_entries?: Maybe<Scalars['Int']>;
  /** The total pages of the query */
  total_pages?: Maybe<Scalars['String']>;
};

/** A Single Expense */
export type Expense = {
  created_at: Scalars['String'];
  currency_symbol?: Maybe<query_getExpenses_expenses_items_currency_symbol>;
  document_date?: Maybe<Scalars['String']>;
  document_id?: Maybe<Scalars['String']>;
  document_type?: Maybe<Scalars['String']>;
  file_name: Scalars['String'];
  file_url: Scalars['String'];
  foreign_total_for_payment?: Maybe<Scalars['Float']>;
  original_file_name?: Maybe<Scalars['String']>;
  provider: Scalars['String'];
  provider_business_num: Scalars['String'];
  recognized_vat_payment: Scalars['Float'];
  remarks?: Maybe<Scalars['String']>;
  status_classification: Scalars['String'];
  system_id: Scalars['Int'];
  total_for_payment: Scalars['Float'];
  total_for_vat: Scalars['Float'];
  updated_at: Scalars['String'];
  vat_payment: Scalars['Float'];
};

export type query_getExpenses_expenses_items_currency_symbol =
  | 'EUR'
  | 'USD'
  | 'ILS';

export type getExpensesRequest_Input = {
  api_user?: InputMaybe<Scalars['String']>;
  query_options?: InputMaybe<queryInput_getExpenses_query_options_Input>;
};

export type queryInput_getExpenses_query_options_Input = {
  updated_from?: InputMaybe<Scalars['String']>;
  updated_to?: InputMaybe<Scalars['String']>;
  created_from?: InputMaybe<Scalars['String']>;
  created_to?: InputMaybe<Scalars['String']>;
  document_date_from?: InputMaybe<Scalars['String']>;
  document_date_to?: InputMaybe<Scalars['String']>;
  document_id?: InputMaybe<Scalars['String']>;
  /** default: -100000000 */
  system_id?: InputMaybe<Scalars['Int']>;
  order?: InputMaybe<queryInput_getExpenses_query_options_order>;
  /** default: 1 */
  page?: InputMaybe<Scalars['Int']>;
  /** default: 50 */
  per_page?: InputMaybe<Scalars['Int']>;
};

export type queryInput_getExpenses_query_options_order =
  | 'document_date';

export type WithIndex<TObject> = TObject & Record<string, any>;
export type ResolversObject<TObject> = WithIndex<TObject>;

export type ResolverTypeWrapper<T> = Promise<T> | T;


export type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
  resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs>;

export type ResolverFn<TResult, TParent, TContext, TArgs> = (
  parent: TParent,
  args: TArgs,
  context: TContext,
  info: GraphQLResolveInfo
) => Promise<TResult> | TResult;

export type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (
  parent: TParent,
  args: TArgs,
  context: TContext,
  info: GraphQLResolveInfo
) => AsyncIterable<TResult> | Promise<AsyncIterable<TResult>>;

export type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (
  parent: TParent,
  args: TArgs,
  context: TContext,
  info: GraphQLResolveInfo
) => TResult | Promise<TResult>;

export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
  subscribe: SubscriptionSubscribeFn<{ [key in TKey]: TResult }, TParent, TContext, TArgs>;
  resolve?: SubscriptionResolveFn<TResult, { [key in TKey]: TResult }, TContext, TArgs>;
}

export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
  subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
  resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}

export type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> =
  | SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs>
  | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;

export type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> =
  | ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>)
  | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;

export type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (
  parent: TParent,
  context: TContext,
  info: GraphQLResolveInfo
) => Maybe<TTypes> | Promise<Maybe<TTypes>>;

export type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;

export type NextResolverFn<T> = () => Promise<T>;

export type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (
  next: NextResolverFn<TResult>,
  parent: TParent,
  args: TArgs,
  context: TContext,
  info: GraphQLResolveInfo
) => TResult | Promise<TResult>;

/** Mapping between all available schema types and the resolvers types */
export type ResolversTypes = ResolversObject<{
  Query: ResolverTypeWrapper<{}>;
  getExpensesResponse: ResolverTypeWrapper<getExpensesResponse>;
  String: ResolverTypeWrapper<Scalars['String']>;
  Int: ResolverTypeWrapper<Scalars['Int']>;
  Expense: ResolverTypeWrapper<Expense>;
  Float: ResolverTypeWrapper<Scalars['Float']>;
  query_getExpenses_expenses_items_currency_symbol: query_getExpenses_expenses_items_currency_symbol;
  getExpensesRequest_Input: getExpensesRequest_Input;
  queryInput_getExpenses_query_options_Input: queryInput_getExpenses_query_options_Input;
  queryInput_getExpenses_query_options_order: queryInput_getExpenses_query_options_order;
  Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
}>;

/** Mapping between all available schema types and the resolvers parents */
export type ResolversParentTypes = ResolversObject<{
  Query: {};
  getExpensesResponse: getExpensesResponse;
  String: Scalars['String'];
  Int: Scalars['Int'];
  Expense: Expense;
  Float: Scalars['Float'];
  getExpensesRequest_Input: getExpensesRequest_Input;
  queryInput_getExpenses_query_options_Input: queryInput_getExpenses_query_options_Input;
  Boolean: Scalars['Boolean'];
}>;

export type QueryResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['Query'] = ResolversParentTypes['Query']> = ResolversObject<{
  getExpenses?: Resolver<Maybe<ResolversTypes['getExpensesResponse']>, ParentType, ContextType, Partial<QuerygetExpensesArgs>>;
}>;

export type getExpensesResponseResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['getExpensesResponse'] = ResolversParentTypes['getExpensesResponse']> = ResolversObject<{
  description?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  expenses?: Resolver<Maybe<Array<Maybe<ResolversTypes['Expense']>>>, ParentType, ContextType>;
  next_page?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
  result?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
  total_entries?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
  total_pages?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
  __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
}>;

export type ExpenseResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['Expense'] = ResolversParentTypes['Expense']> = ResolversObject<{
  created_at?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  currency_symbol?: Resolver<Maybe<ResolversTypes['query_getExpenses_expenses_items_currency_symbol']>, ParentType, ContextType>;
  document_date?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
  document_id?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
  document_type?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
  file_name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  file_url?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  foreign_total_for_payment?: Resolver<Maybe<ResolversTypes['Float']>, ParentType, ContextType>;
  original_file_name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
  provider?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  provider_business_num?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  recognized_vat_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
  remarks?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
  status_classification?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  system_id?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
  total_for_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
  total_for_vat?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
  updated_at?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
  vat_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
  __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
}>;

export type Resolvers<ContextType = MeshContext> = ResolversObject<{
  Query?: QueryResolvers<ContextType>;
  getExpensesResponse?: getExpensesResponseResolvers<ContextType>;
  Expense?: ExpenseResolvers<ContextType>;
}>;


import { MeshContext as BaseMeshContext, MeshInstance } from '@graphql-mesh/runtime';

import { InContextSdkMethod } from '@graphql-mesh/types';


    export namespace PayperTypes {
      export type Maybe<T> = T | null;
export type InputMaybe<T> = Maybe<T>;
export type Exact<T extends { [key: string]: unknown }> = { [K in keyof T]: T[K] };
export type MakeOptional<T, K extends keyof T> = Omit<T, K> & { [SubKey in K]?: Maybe<T[SubKey]> };
export type MakeMaybe<T, K extends keyof T> = Omit<T, K> & { [SubKey in K]: Maybe<T[SubKey]> };
/** All built-in and custom scalars, mapped to their actual values */
export type Scalars = {
  ID: string;
  /** The `String` scalar type represents textual data, represented as UTF-8 character sequences. The String type is most often used by GraphQL to represent free-form human-readable text. */
  String: string;
  Boolean: boolean;
  /** The `Int` scalar type represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1. */
  Int: number;
  /** The `Float` scalar type represents signed double-precision fractional values as specified by [IEEE 754](https://en.wikipedia.org/wiki/IEEE_floating_point). */
  Float: number;
};

export type Query = {
  getExpenses?: Maybe<getExpensesResponse>;
};


export type QuerygetExpensesArgs = {
  input?: InputMaybe<getExpensesRequest_Input>;
};

export type getExpensesResponse = {
  description: Scalars['String'];
  /** An array of JSON of the search */
  expenses?: Maybe<Array<Maybe<Expense>>>;
  /** The next available page */
  next_page?: Maybe<Scalars['String']>;
  result: Scalars['Int'];
  /** The total size of the query */
  total_entries?: Maybe<Scalars['Int']>;
  /** The total pages of the query */
  total_pages?: Maybe<Scalars['String']>;
};

/** A Single Expense */
export type Expense = {
  created_at: Scalars['String'];
  currency_symbol?: Maybe<query_getExpenses_expenses_items_currency_symbol>;
  document_date?: Maybe<Scalars['String']>;
  document_id?: Maybe<Scalars['String']>;
  document_type?: Maybe<Scalars['String']>;
  file_name: Scalars['String'];
  file_url: Scalars['String'];
  foreign_total_for_payment?: Maybe<Scalars['Float']>;
  original_file_name?: Maybe<Scalars['String']>;
  provider: Scalars['String'];
  provider_business_num: Scalars['String'];
  recognized_vat_payment: Scalars['Float'];
  remarks?: Maybe<Scalars['String']>;
  status_classification: Scalars['String'];
  system_id: Scalars['Int'];
  total_for_payment: Scalars['Float'];
  total_for_vat: Scalars['Float'];
  updated_at: Scalars['String'];
  vat_payment: Scalars['Float'];
};

export type query_getExpenses_expenses_items_currency_symbol =
  | 'EUR'
  | 'USD'
  | 'ILS';

export type getExpensesRequest_Input = {
  api_user?: InputMaybe<Scalars['String']>;
  query_options?: InputMaybe<queryInput_getExpenses_query_options_Input>;
};

export type queryInput_getExpenses_query_options_Input = {
  updated_from?: InputMaybe<Scalars['String']>;
  updated_to?: InputMaybe<Scalars['String']>;
  created_from?: InputMaybe<Scalars['String']>;
  created_to?: InputMaybe<Scalars['String']>;
  document_date_from?: InputMaybe<Scalars['String']>;
  document_date_to?: InputMaybe<Scalars['String']>;
  document_id?: InputMaybe<Scalars['String']>;
  /** default: -100000000 */
  system_id?: InputMaybe<Scalars['Int']>;
  order?: InputMaybe<queryInput_getExpenses_query_options_order>;
  /** default: 1 */
  page?: InputMaybe<Scalars['Int']>;
  /** default: 50 */
  per_page?: InputMaybe<Scalars['Int']>;
};

export type queryInput_getExpenses_query_options_order =
  | 'document_date';

    }
    export type QueryPayperSdk = {
  /** undefined **/
  getExpenses: InContextSdkMethod<PayperTypes.Query['getExpenses'], PayperTypes.QuerygetExpensesArgs, MeshContext>
};

export type MutationPayperSdk = {

};

export type SubscriptionPayperSdk = {

};

export type PayperContext = {
      ["Payper"]: { Query: QueryPayperSdk, Mutation: MutationPayperSdk, Subscription: SubscriptionPayperSdk },
    };

export type MeshContext = PayperContext & BaseMeshContext;


import { getMesh } from '@graphql-mesh/runtime';
import { MeshStore, FsStoreStorageAdapter } from '@graphql-mesh/store';
import { path as pathModule } from '@graphql-mesh/cross-helpers';
import { fileURLToPath } from '@graphql-mesh/utils';
import ExternalModule_0 from 'ts-node/register/transpile-only';
import ExternalModule_1 from '@graphql-mesh/cache-inmemory-lru';
import ExternalModule_2 from '@graphql-mesh/json-schema';
import ExternalModule_3 from '@graphql-mesh/merger-bare';
import ExternalModule_4 from '@graphql-mesh/transform-resolvers-composition';
import ExternalModule_5 from './sources/Payper/jsonSchemaBundle';
import ExternalModule_6 from './../src/resolvers/getExpensesResolver';

const importedModules: Record<string, any> = {
  // @ts-ignore
  ["ts-node/register/transpile-only"]: ExternalModule_0,
  // @ts-ignore
  ["@graphql-mesh/cache-inmemory-lru"]: ExternalModule_1,
  // @ts-ignore
  ["@graphql-mesh/json-schema"]: ExternalModule_2,
  // @ts-ignore
  ["@graphql-mesh/merger-bare"]: ExternalModule_3,
  // @ts-ignore
  ["@graphql-mesh/transform-resolvers-composition"]: ExternalModule_4,
  // @ts-ignore
  [".mesh/sources/Payper/jsonSchemaBundle"]: ExternalModule_5,
  // @ts-ignore
  ["src/resolvers/getExpensesResolver"]: ExternalModule_6
};

const baseDir = pathModule.join(__dirname, '..');

const importFn = (moduleId: string) => {
  const relativeModuleId = (pathModule.isAbsolute(moduleId) ? pathModule.relative(baseDir, moduleId) : moduleId).split('\\').join('/').replace(baseDir + '/', '');
  if (!(relativeModuleId in importedModules)) {
    throw new Error(`Cannot find module '${relativeModuleId}'.`);
  }
  return Promise.resolve(importedModules[relativeModuleId]);
};

const rootStore = new MeshStore('.mesh', new FsStoreStorageAdapter({
  cwd: baseDir,
  importFn,
}), {
  readonly: true,
  validate: false
});

import { GetMeshOptions } from '@graphql-mesh/runtime';
import { YamlConfig } from '@graphql-mesh/types';
import { parse } from 'graphql';
import 'ts-node/register/transpile-only';
import { PubSub } from '@graphql-mesh/utils';
import MeshCache from '@graphql-mesh/cache-inmemory-lru';
import { DefaultLogger } from '@graphql-mesh/utils';
import JsonSchemaHandler from '@graphql-mesh/json-schema'
import BareMerger from '@graphql-mesh/merger-bare';
import ResolversCompositionTransform from '@graphql-mesh/transform-resolvers-composition';
import { resolveAdditionalResolvers } from '@graphql-mesh/utils';
import { parseWithCache } from '@graphql-mesh/utils';
export const rawConfig: YamlConfig.Config = {"sources":[{"name":"Payper","handler":{"jsonSchema":{"baseUrl":"https://payper.co.il/app/api","operationHeaders":{"API_KEY":"{env.PAYPER_MESH_AUTH_TOKEN}","Content-Type":"application/json","Accept":"application/json"},"operations":[{"type":"Query","field":"getExpenses","path":"/pull_expenses","method":"POST","requestSchema":"./json-schemas/payperSchema.json#/definitions/getExpensesRequest","responseSchema":"./json-schemas/payperSchema.json#/definitions/getExpensesResponse"}]}},"transforms":[{"resolversComposition":{"mode":"bare","compositions":[{"resolver":"Query.getExpenses","composer":"src/resolvers/getExpensesResolver"}]}}]}],"serve":{"browser":false},"sdk":{"generateOperations":{"selectionSetDepth":2}},"require":["ts-node/register/transpile-only"]} as any
export async function getMeshOptions(): Promise<GetMeshOptions> {
const pubsub = new PubSub();
const cache = new (MeshCache as any)({
      ...(rawConfig.cache || {}),
      importFn,
      store: rootStore.child('cache'),
      pubsub,
    } as any)
const sourcesStore = rootStore.child('sources');
const logger = new DefaultLogger('🕸️');
const sources = [];
const transforms = [];
const payperTransforms = [];
const additionalTypeDefs = [] as any[];
const payperHandler = new JsonSchemaHandler({
              name: rawConfig.sources[0].name,
              config: rawConfig.sources[0].handler["jsonSchema"],
              baseDir,
              cache,
              pubsub,
              store: sourcesStore.child(rawConfig.sources[0].name),
              logger: logger.child(rawConfig.sources[0].name),
              importFn
            });
const merger = new(BareMerger as any)({
        cache,
        pubsub,
        logger: logger.child('BareMerger'),
        store: rootStore.child('bareMerger')
      })
payperTransforms.push(
                new ResolversCompositionTransform({
                  apiName: rawConfig.sources[0].name,
                  config: rawConfig.sources[0].transforms[0]["resolversComposition"],
                  baseDir,
                  cache,
                  pubsub,
                  importFn
                })
              );
sources.push({
          name: 'Payper',
          handler: payperHandler,
          transforms: payperTransforms
        })
const additionalResolversRawConfig = [];
const additionalResolvers = await resolveAdditionalResolvers(
      baseDir,
      additionalResolversRawConfig,
      importFn,
      pubsub
  )
const liveQueryInvalidations = rawConfig.liveQueryInvalidations;
const additionalEnvelopPlugins = [];
const documents = documentsInSDL.map((documentSdl: string, i: number) => ({
              rawSDL: documentSdl,
              document: parseWithCache(documentSdl),
              location: `document_${i}.graphql`,
            }))

  return {
    sources,
    transforms,
    additionalTypeDefs,
    additionalResolvers,
    cache,
    pubsub,
    merger,
    logger,
    liveQueryInvalidations,
    additionalEnvelopPlugins,
    documents,
  };
}

export const documentsInSDL = /*#__PURE__*/ [];

export async function getBuiltMesh(): Promise<MeshInstance<MeshContext>> {
  const meshConfig = await getMeshOptions();
  return getMesh<MeshContext>(meshConfig);
}

export async function getMeshSDK<TGlobalContext = any, TOperationContext = any>(globalContext?: TGlobalContext) {
  const { sdkRequesterFactory } = await getBuiltMesh();
  return getSdk<TOperationContext>(sdkRequesterFactory(globalContext));
}
export type getExpenses_queryQueryVariables = Exact<{
  input?: InputMaybe<getExpensesRequest_Input>;
}>;


export type getExpenses_queryQuery = { getExpenses?: Maybe<(
    Pick<getExpensesResponse, 'description' | 'next_page' | 'result' | 'total_entries' | 'total_pages'>
    & { expenses?: Maybe<Array<Maybe<Pick<Expense, 'created_at' | 'currency_symbol' | 'document_date' | 'document_id' | 'document_type' | 'file_name' | 'file_url' | 'foreign_total_for_payment' | 'original_file_name' | 'provider' | 'provider_business_num' | 'recognized_vat_payment' | 'remarks' | 'status_classification' | 'system_id' | 'total_for_payment' | 'total_for_vat' | 'updated_at' | 'vat_payment'>>>> }
  )> };


export const getExpenses_queryDocument = gql`
    query getExpenses_query($input: getExpensesRequest_Input) {
  getExpenses(input: $input) {
    description
    expenses {
      created_at
      currency_symbol
      document_date
      document_id
      document_type
      file_name
      file_url
      foreign_total_for_payment
      original_file_name
      provider
      provider_business_num
      recognized_vat_payment
      remarks
      status_classification
      system_id
      total_for_payment
      total_for_vat
      updated_at
      vat_payment
    }
    next_page
    result
    total_entries
    total_pages
  }
}
    ` as unknown as DocumentNode<getExpenses_queryQuery, getExpenses_queryQueryVariables>;


export type Requester<C= {}> = <R, V>(doc: DocumentNode, vars?: V, options?: C) => Promise<R>
export function getSdk<C>(requester: Requester<C>) {
  return {
    getExpenses_query(variables?: getExpenses_queryQueryVariables, options?: C): Promise<getExpenses_queryQuery> {
      return requester<getExpenses_queryQuery, getExpenses_queryQueryVariables>(getExpenses_queryDocument, variables, options);
    }
  };
}
export type Sdk = ReturnType<typeof getSdk>;